#' Label for category of activities (from floodam.building)
#'
#' A dataset containing the label (currently in French) corresponding with
#' the typology of activities used within floodam.building
#'
#' @format A data frame with 21 rows and 2 variables:
#' \describe{
#'      \item{code}{character, code of the type.}
#'      \item{label.fr}{character, label in French corresponding with the code.}
#' }
"category_label"

#' Perimeter of so-ii experimental site
#'
#' A dataset containing the commune pertaining to so-ii experimental site with
#' useful information to make subsets
#'
#' @format A data frame with 78 rows and 6 variables:
#' \describe{
#'      \item{commune}{integer, INSEE code for the commune.}
#'      \item{commune_name}{character, name of the commune.}
#'      \item{syble}{logical, is the commune belonging to Syble.}
#'      \item{symbo}{logical, is the commune belonging to Symbo.}
#'      \item{epci}{character, name of the EPCI to which the commune belongs.}
#'      \item{type}{character, type of commune between urban, periurban and
#'      rural.}
#' }
"commune_so_ii"

#' Region definition in France
#'
#' This dataset gives the correspondance between code and French label in use
#' in France.
#'
#' @format A data frame with 101 rows and 2 variables:
#' \describe{
#'      \item{code}{character, INSEE code of department.}
#'      \item{label.fr}{character, name of department as defined by INSEE.}
#'      \item{region}{character, INSEE code of region where department is
#'      located.}
#' }
"department"

#' Variables kept in EAIP
#'
#' This dataset controls which variables are kept when applying adapt.eaip.
#' The choice of the variables has been made by inspecting all EAIP shapefiles,
#' and by keeping most common variables inside, removing variables without added 
#' information (such as R, V, B).
#'
#' @format A character vector with 12 elements.
"eaip_variable"

#' Label coming from NACE typology
#'
#' A dataset containing the label (currently in English and French)
#' corresponding with the NACE typology of activities at levels 1 to 4 included.
#'
#' @format A data frame with 996 rows and 4 variables:
#' \describe{
#'      \item{level}{integer, level of the type.}
#'      \item{code}{character, code of the type.}
#'      \item{label.en}{character, label in English corresponding with the
#'      code.}
#'      \item{label.fr}{character, label in French corresponding with the code.}
#' }
"nace_label"

#' Typology of activities with additional information
#'
#' A dataset containing the typology of activities at different level,
#' with some useful additional information from French database esane.
#'
#' @format A data frame with 732 rows and 26 variables:
#' \describe{
#'      \item{APE.05}{character, category at level 5, specific to France.}
#'      \item{APE.01}{character, category at level 1, compatible with NACE.}
#'      \item{APE.02}{character, category at level 2, compatible with NACE.}
#'      \item{APE.03}{character, category at level 3, compatible with NACE.}
#'      \item{APE.04}{character, category at level 4, compatible with NACE.}
#'      \item{type}{character, type of activity, compatible with French damage
#'      modelling.}
#'      \item{category}{character, vulnerability category of activity,
#'      compatible with French damage modelling.}
#'      \item{leased}{character, TO BE SPECIFIED.}
#'      \item{level}{character, level at which following data could be
#'      retrieved.}
#'      \item{n}{numeric, number of activity of given category.}
#'      \item{employee}{numeric, number of employee of given category.}
#'      \item{equipment}{numeric, value of equipment in € of given category.}
#'      \item{stock}{numeric, value of stock in € of given category.}
#'      \item{transport}{numeric, part of transport equipment within equipment
#'      for given category.}
#'      \item{virtual.corrected}{numeric, TO BE SPECIFIED.}
#'      \item{e.emp}{numeric, value of equipment per employee in € of given
#'      category.}
#'      \item{s.emp}{numeric, value of stock per employee in € of given
#'      category.}
#'      \item{e.ent}{numeric, value of stock per activity in € of given
#'      category.}
#'      \item{s.ent}{numeric, value of stock per activty in € of given
#'      category.}
#'      \item{ACTENTNOMESS}{numeric, original data from ESANE.}
#'      \item{EMPSALNOMESS}{numeric, original data from ESANE.}
#'      \item{BAC123VALESE}{numeric, original data from ESANE.}
#'      \item{BAC124VALESE}{numeric, original data from ESANE.}
#'      \item{BAC152VALESE}{numeric, original data from ESANE.}
#'      \item{BAC155VALESE}{numeric, original data from ESANE.}
#'      \item{BAC156VALESE}{numeric, original data from ESANE.}
#' }
"naf_esane"


#' Label (in French) coming from NAF typology
#'
#' A dataset containing the label in French corresponding with
#' the NAF typology of activities at levels 1 to 5 included.
#'
#' @format A data frame with 1728 rows and 3 variables:
#' \describe{
#'      \item{level}{integer, level of the type.}
#'      \item{code}{character, code of the type.}
#'      \item{label.fr}{character, label in French corresponding with the code.}
#' }
"naf_label"

#' Nomenclature of Corine Land Cover with color definitions
#'
#' A dataset containing the labels in French and English corresponding with
#' the Corine Land Cover (CLC) typology. It also gives color definition for
#' each types. Those colors are those that may be used internally in
#' floodam.data and also those given by the French ministrey of environment.
#'
#' @format A data frame with 28 rows and 2 variables:
#' \describe{
#'      \item{level}{character, level of classification in CLC.}
#'      \item{clc}{character, classification in CLC.}
#'      \item{clc_label_fr}{character, label in French corresponding with the
#'      clc code.}
#'      \item{clc_label_en}{character, label in English corresponding with the
#'      clc code.}
#'      \item{col}{character, color definition for floodam.data usage.}
#'      \item{col_fr}{character, color definition by the French ministery of
#'      environment.}
#' }
"nomenclature_clc"

#' Nomenclature (in French) of RPG version 1.0
#'
#' A dataset containing the label in French corresponding with
#' the version 1.0 of the RPG typology for cultivated plots.
#'
#' @format A data frame with 28 rows and 2 variables:
#' \describe{
#'      \item{group}{character, code of the group of crops.}
#'      \item{group_label_fr}{character, label in French corresponding with the
#'      group code.}
#' }
"nomenclature_rpg_1"

#' Nomenclature (in French) of RPG version 2.0
#'
#' A dataset containing the label in French corresponding with
#' the version 2.0 of the RPG typology for cultivated plots (should work up to
#' year 2018).
#'
#' @format A data frame with 392 rows and 3 variables:
#' \describe{
#'      \item{culture}{character, code of the crop.}
#'      \item{group}{character, code of the group to which the crop belongs.}
#'      \item{culture_label_fr}{character, label in French corresponding with
#'      the crop code.}
#' }
"nomenclature_rpg_2"

#' Information on the variables of Admin Express version 2-0
#'
#' This dataset controls also default behaviour of what variables are kept,
#' their desired type. It may be used as a value in `adapt_admin_express()`
#' for old version of Admin Express.
#'
#' @format A data frame with 26 rows and 11 variables:
#' \describe{
#'      \item{name}{character, name of variables used in floodam.data.}
#'      \item{name_origin}{character, name of variables as defined in original
#'      data.}
#'      \item{layer}{character, name of layer where the variables are used.}
#'      \item{order}{integer, order of the variables in original data.}
#'      \item{keep}{logical, defined if floodam.data will keep this variable.}
#'      \item{type}{character, type that will be used within floodam.data.}
#'      \item{label_fr}{character, variables description in French.}
#'      \item{source}{character, source of the variables.}
#'      \item{length_source}{integer, length of variables in source.}
#'      \item{type_source}{character, type of variables in source.}
#'      \item{comment}{character, some comments on choice made.}
#' }
"scheme_admin_express_2_0"

#' Information on the variables of Admin Express version 3-1
#'
#' This dataset controls also default behaviour of what variables are kept,
#' their desired type. It is used as default value in
#' `adapt_admin_express()`.
#'
#' @format A data frame with 24 rows and 11 variables:
#' \describe{
#'      \item{name}{character, name of variables used in floodam.data.}
#'      \item{name_origin}{character, name of variables as defined in original
#'      data.}
#'      \item{layer}{character, name of layer where the variables is used.}
#'      \item{order}{integer, order of the variables in original data.}
#'      \item{keep}{logical, defined if floodam.data will keep this variable.}
#'      \item{type}{character, type that will be used within floodam.data.}
#'      \item{label_fr}{character, variables description in French.}
#'      \item{source}{character, source of the variables.}
#'      \item{length_source}{integer, length of variables in source.}
#'      \item{type_source}{character, type of variables in source.}
#'      \item{comment}{character, some comments on choice made.}
#' }
"scheme_admin_express_3_1"

#' Information on the variables of BAN
#'
#' This dataset controls also default behaviour of what variables are kept,
#' their desired type. It is used as default value in adapt_ban.
#'
#' @format A data frame with 25 rows and 12 variables:
#' \describe{
#'      \item{name}{character, name of variables used in floodam.data.}
#'      \item{name_origin}{character, name of variables as defined in
#'          original data.}
#'      \item{order}{integer, order of the variables in original data.}
#'      \item{keep}{logical, defined if floodam.data will keep this variable.}
#'      \item{type}{character, type that will be used within floodam.data.}
#'      \item{label_fr}{character, variables description in French.}
#'      \item{source}{character, source of the variables.}
#'      \item{length_source}{integer, length of variables in source.}
#'      \item{type_source}{character, type of variables in source.}
#'      \item{comment}{character, some additionnal comments to better understand
#'      variable.}
#' }
"scheme_ban"

#' Information on the variables of BD TOPO version 3.0
#'
#' This dataset controls also default behaviour of what variables are kept,
#' their desired type. It is used as default value in adapt.bd_topo.
#'
#' @format A data frame with 25 rows and 12 variables:
#' \describe{
#'      \item{name}{character, name of variables used in floodam.data.}
#'      \item{name_origin_gpkg}{character, name of variables as defined in
#'          original data for gkpg archives.}
#'      \item{name_origin_shp}{character, name of variables as defined in
#'          original data for shp files.}
#'      \item{layer}{character, name of layer where the variables is used.}
#'      \item{order}{integer, order of the variables in original data.}
#'      \item{keep}{logical, defined if floodam.data will keep this variable.}
#'      \item{type}{character, type that will be used within floodam.data.}
#'      \item{unit}{character, unit of numeric data.}
#'      \item{label_fr}{character, variables description in French.}
#'      \item{source}{character, source of the variables.}
#'      \item{length_source}{integer, length of variables in source.}
#'      \item{type_source}{character, type of variables in source.}
#'      \item{comment}{character, some additionnal comments to better understand
#'      variable.}
#' }
"scheme_bd_topo_3"

#' Scheme for theme azi in gaspar DB
#'
"scheme_gaspar_azi"

#' Scheme for theme catnat in gaspar DB
#'
"scheme_gaspar_catnat"

#' Scheme for theme risq in gaspar DB
#'
"scheme_gaspar_risq"

#' Scheme for theme risq in gaspar DB
#'
"scheme_gaspar_pprn"

#' Informations on the variables of the series 'Logements (France hors Mayotte)'
#' from the INSEE
#'
#' This dataset controls also default behaviour of what variables are kept,
#' their desired type. It is used as default value in adapt_insee.
#'
#' @format A data frame with 7 rows and 11 variables:
#' \describe{
#'      \item{name}{character, name of variables used in floodam.data.}
#'      \item{name_origin}{character, name of variables as defined in original
#'      data.}
#'      \item{order}{integer, order of the variables in original data.}
#'      \item{keep}{logical, defined if floodam.data will keep this variable.}
#'      \item{type}{character, type that will be used within floodam.data.}
#'      \item{label_fr}{character, variables description in French.}
#'      \item{source}{character, source of the variables.}
#'      \item{length_source}{integer, length of variables in source.}
#'      \item{type_source}{character, type of variables in source.}
#'      \item{comment}{character, some comments on choice made.}
#' }
"scheme_insee_logement_2019"

#' Information on the variables of RPG version 1.0
#'
#' This dataset controls also default behaviour of what variables are kept,
#' their desired type. It is used as default value in adapt_rpg.
#'
#' @format A data frame with 9 rows and 11 variables:
#' \describe{
#'      \item{name}{character, name of variables used in floodam.data.}
#'      \item{name_origin}{character, name of variables as defined in original
#'      data.}
#'      \item{layer}{character, name of layer where the variables is used.}
#'      \item{order}{integer, order of the variables in original data.}
#'      \item{keep}{logical, defined if floodam.data will keep this variable.}
#'      \item{type}{character, type that will be used within floodam.data.}
#'      \item{label_fr}{character, variables description in French.}
#'      \item{source}{character, source of the variables.}
#'      \item{length_source}{integer, length of variables in source.}
#'      \item{type_source}{character, type of variables in source.}
#'      \item{comment}{character, some comments on choice made.}
#' }
"scheme_rpg_1"

#' Information on the variables of RPG version 2.0
#'
#' This dataset controls also default behaviour of what variables are kept,
#' their desired type. It is used as default value in adapt_rpg.
#'
#' @format A data frame with 7 rows and 11 variables:
#' \describe{
#'      \item{name}{character, name of variables used in floodam.data.}
#'      \item{name_origin}{character, name of variables as defined in original
#'      data.}
#'      \item{layer}{character, name of layer where the variables are used.}
#'      \item{order}{integer, order of the variables in original data.}
#'      \item{keep}{logical, defined if floodam.data will keep this variable.}
#'      \item{type}{character, type that will be used within floodam.data.}
#'      \item{label_fr}{character, variables description in French.}
#'      \item{source}{character, source of the variables.}
#'      \item{length_source}{integer, length of variables in source.}
#'      \item{type_source}{character, type of variables in source.}
#'      \item{comment}{character, some comments on choice made.}
#' }
"scheme_rpg_2"

#' Information on the variables of geolocalized sirene data
#'
#' A dataset containing the description of variables in geolocalized sirene
#' data. It includes information that is coming from the 2019 version of Sirene
#' format as maintained by INSEE and information that is coming from 'cquest'
#' process for geolocalizing. This dataset controls also default behaviour of
#' what variables are kept, their desired type. It is used as default value in
#' adapt.geo_sirene.
#'
#' @format A data frame with 57 rows and 10 variables:
#' \describe{
#'      \item{name}{character, name of variables used in floodam.data.}
#'      \item{name.origin}{character, name of variables as defined in original
#'      data.}
#'      \item{order}{integer, order of the variables in original data.}
#'      \item{keep}{logical, defined if floodam.data will keep this variable.}
#'      \item{type}{character, type that will be used within floodam.data.}
#'      \item{label.french}{character, variables description in French.}
#'      \item{source}{character, source of the variables.}
#'      \item{length.source}{integer, length of variables in source.}
#'      \item{type.source}{character, type of variables in source.}
#'      \item{comment}{character, some comments on choice made.}
#' }
"scheme_sirene_2019"

#' Information on na.value in geolocalized sirene data
#'
#' A dataset containing the description of admissibile na.value other than "" in
#' geolocalized sirene data. It is used as default value in adapt.geo_sirene.
#'
#' @format A data frame with 3 rows and 2 variables:
#' \describe{
#'      \item{name}{character, name of variable as used in floodam.data.}
#'      \item{na.value}{character, value that is to be considered as na.value.}
#' }
"scheme_sirene_na"

#' Region definition in France
#'
#' This dataset gives the correspondance between code and French label in use
#' in France.
#'
#' @format A data frame with 18 rows and 2 variables:
#' \describe{
#'      \item{code}{character, INSEE code of region.}
#'      \item{label.fr}{character, name of region as defined by INSEE.}
#' }
"region"

#' Classification of hazard events in catnat (gaspar DB)
#'
"catnat_classification"

#' Classification of hazard events in pprn (gaspar DB)
#'
"pprn_classification"

#' Scheme to rename levels of variable 'nature' in the BT TOPO version 3.0
#'
#' This dataset controls how the categories in the variable 'nature' are to be 
#' renamed.
#'
#' @format A data frame with 14 rows and 2 variables:
#' \describe{
#'      \item{nature}{character, name of categories originally used variable 
#'      'nature' of the bdtopo.}
#'      \item{classification_fr}{character, name of categories to be used to
#'      transform the categories in variable 'nature'.}
#'      \item{order}{character, order of the level in the factor variable.}
#' }
"bd_topo_nature_reclass"

#' Scheme to rename levels of variable 'material_wall' in BD Topo version 3.0
#'
#' This dataset controls how the categories in the variable 'material_wall' are
#' to be renamed.
#'
#' @format A data frame with 64 rows and 4 variables:
#' \describe{
#'      \item{material_wall}{character, categories of materials.}
#'      \item{label_wall_bdtopo}{character, originally given name to the
#'      categories of materials in the BDTopo.}
#'      \item{label_wall_fr}{character, simplified name to the categories of
#'      materials in French.}
#'      \item{combined_wall}{character, TRUE if two categories of materials are
#'      mixed.}
#' }
"bd_topo_wall"

#' Scheme to rename levels of variable 'material_roof' in BD Topo version 3.0
#'
#' This dataset controls how the categories in the variable 'material_roof' are
#' to be renamed.
#'
#' @format A data frame with 36 rows and 4 variables:
#' \describe{
#'      \item{material_roof}{character, categories of materials.}
#'      \item{label_roof_bdtopo}{character, originally given name to the
#'      categories of materials in BD Topo.}
#'      \item{label_roof_fr}{character, simplified name to the categories of
#'      materials in French.}
#'      \item{combined_roof}{character, TRUE if two categories of materials are
#'      mixed.}
#' }
"bd_topo_roof"
