#' @title Decompress a 7z archive looking for gpkg file
#' 
#' @description
#' The function 'gpkg_from_7z' uses a system call to 7z to uncompress a 7z
#' archive. It looks specifically for a gkpg file inside the 7z archive.
#'
#' @param archive character, path to the 7z archive.
#'
#' @return charcater, temp path to th gpkg file extracted.
#'
#' @export
#'
#' @encoding UTF-8
#' @author Frédéric Grelot

gpkg_from_7z = function(archive) {
    path_temp = tempdir()
    gpkg = gsub(
        ".+ ", "",
        grep(
            "gpkg$",
            system(sprintf("7z l %s 2>&1", archive), intern = TRUE),
            value = TRUE
        )
    )
    system(
        sprintf("7z e -y %s -o%s %s", archive, path_temp, gpkg),
        ignore.stdout = TRUE, wait = TRUE
    )
    return(path_temp)
}

#' @title Decompress a 7z archive looking for shp file
#' 
#' @description
#' The function 'shp_from_7z' uses a system call to 7z to uncompress a 7z
#' archive. It looks specifically for a shp file inside the 7z archive.
#'
#' @param archive character, path to the 7z archive.
#'
#' @return charcater, temp path to th shp file extracted.
#'
#' @export
#'
#' @encoding UTF-8
#' @author Frédéric Grelot

shp_from_7z = function(archive) {
    path_temp = tempdir()
    shp = gsub(
        ".+ ", "",
        grep(
            "shp$",
            system(sprintf("7z l %s 2>&1", archive), intern = TRUE),
            value = TRUE
        )
    )
    system(
        sprintf("7z e -y %s -o%s %s", archive, path_temp, shp),
        ignore.stdout = TRUE, wait = TRUE
    )
    return(path_temp)
}

#' @title Read a specific layer inside a gpkg file
#' 
#' @description
#' The function 'read_gpkg_layer' embeds sf::st_read to read a gpkg file from
#' a gkpg archive.
#'
#' @param path character, path where to find the 'gpkg' file.
#' @param layer character, layer to be read.
#' 
#' @return sf object
#'
#' @export
#'
#' @encoding UTF-8
#' @author Frédéric Grelot

read_gpkg_layer = function(path, layer) {
    gpkg = dir(path, ".gpkg$")
    sf::st_read(
        file.path(path, gpkg),
        layer = layer,
        quiet = TRUE
    )
}