#' @title plot of the construction dates of buildings in the context of the 
#' BD-Topo v3
#' 
#' @description
#' The function produces a time series plot of the construction dates of 
#' buildings identified as residential in the BDTopo. The plot is stored as png 
#' image in destination 
#' 
#' @param output_name character. It can be either "building" or "dwelling"
#' @param dataset data.frame
#' @param destination character. Path to folder where tables and figures must be stocked.
#'
#'
#' @export
#'
#' @encoding UTF-8
#' @author David Nortes Martinez

plot_construction_date = function(output_name, dataset, destination){

    # data to be plotted
    aux = table(
        dataset[["date_apparition"]],
        useNA = "no"
    )

    # x-axis labels 
    dates =format(
        as.Date(c(
            seq(
                as.Date(min(dataset[["date_apparition"]], na.rm = TRUE)),
                as.Date(max(dataset[["date_apparition"]], na.rm = TRUE)),
                by = "50 years"
            ),
            as.Date(max(dataset[["date_apparition"]], na.rm = TRUE))
        )),
        "%Y"
    )

    dates_at = format(as.Date(names(aux)), "%Y") %in% dates 

    # generating and saving plot in destination
    grDevices::png(
        file.path(
            destination, 
            "figure", 
            paste0(output_name, "-", "construction_date.png")
        ),
        height = 360, 
        width = 1440
    )
        graphics::par(mar = c(5,5,4,2))
        plot(
            y = unname(aux),
            x = as.Date(names(aux)),
            type = 'h',
            las = 2,
            ylab = "Nombre de constructions",
            xlab = "Ann\u00E9e",
            xaxt = "n",
            main = paste("P\u00E9riode ", 
                format(min(dataset[["date_apparition"]], na.rm = TRUE), "%Y"),
                " -- ",
                format(max(dataset[["date_apparition"]], na.rm = TRUE), "%Y")
                ),
            cex.lab = 2,
            cex.main = 2
        ) 
        graphics::axis(
            side=2, 
            at=seq(0, max(aux), by = 3000), 
            labels=format(seq(0, max(aux), by = 3000), big.mark = " "),
            cex.axis = 2
        )
        graphics::axis.Date(
            side = 1, 
            at = as.Date(names(aux))[dates_at], 
            format ="%Y", 
            labels = TRUE,
            cex.axis = 2,
            cex.lab = 2
        )

    grDevices::dev.off()
}