#' Prepare data from considering a time serie
#'
#' This function uses data.frame extracted by the way of extract.sat.log, and combine them so as to give a
#' time series perspective of those data.frame.
#'
#' @param origin character, path to the directory where journal is stored
#' @param archive string character, pattern to find the journal. If set to NULL, any .log file will be searched.
#' @param destination character, optional path to the directory where results should be saved. If set to NULL,
#' results are not saved.
#'
#' @return A list of data.frame depending on information stored in the journal.
#'
#' @export
#'
#' @encoding UTF-8
#' @author Frédéric Grelot
#' 
#' @examples
#' 
#' \dontrun{
#' origin = "floodam.data/dev/data"
#' archive = "geo_siret"
#' result = prepare.stat.log(origin, archive)
#' }

prepare.stat.log = function(origin, archive, destination = NULL) {

    fun = function(what, result) {
        do.call(rbind,
            mapply(
                function(x, what, date) {cbind(date = date, x[[what]])},
                x = result,
                date = names(result),
                MoreArgs = list(what = what),
                SIMPLIFY = FALSE
            )
        )
    }

    output_pattern = archive

    month = list.dirs(origin, full.names = FALSE, recursive = FALSE)
    if (length(month) == 0) {
        archive = grep(".log$", dir(origin, pattern = archive), value = TRUE)
        month =  sapply(
            regmatches(archive, regexec("([0-9]{4}-[0-9]{2})[.]log$", archive, perl = TRUE)), 
            "[", 2
        )
    } else {
        month = regmatches(month, regexec("^([0-9]{4}-[0-9]{2})$", month, perl = TRUE))
        month = month[sapply(month, length) > 0]
        if(length(month) == 0) return(NULL)
        month = sapply(month, "[", 2)
        origin = file.path(origin, month)
    }
    
    result = structure(
        mapply(extract.stat.log, origin, archive, SIMPLIFY = FALSE),
        names = month
    )


    result = structure(
        lapply(names(result[[1]]), fun, result),
        names = names(result[[1]])
    )

    if (!is.null(destination)) {
        for (name in names(result)) 
            utils::write.csv2(
                result[[name]], 
                file.path(destination, sprintf("%s_%s.csv", output_pattern, name)),
                row.names = FALSE
            )
    }

    return(result)
}
