#' @title Subset dataset with scope
#' 
#' @param dataset dataframe or sf object, the dataset to scope
#' @param scope character vector. Municipality french INSEE code called "Code Officiel Géographique" (COG).
#'
#' @return either a data.frame or a 'sf' objects depending on dataset type
#' 
#' @details The scope is done at the scale of the municipalities
#' 
#' @export
#' 
#' @encoding UTF-8
#' 
#' @examples
#' dataset = data.frame(
#'    id = (1:5),
#'    adresse = letters[1:5], 
#'    commune = c("32456", "36980", "37865", "76543", "34172")
#' )
#' dataset
#' 
#' select_scope(dataset, scope = "34172")
#'
#' select_scope(dataset, scope = c("36980","34172") )
#'
#' # scope's value is out of the dataset
#' select_scope(dataset, scope = "39876")  
#'
#' # Two values are in the scope and one is out
#' select_scope(dataset, scope = c("36980", "34179", "32456")) 

select_scope = function(dataset, scope)  {
    if ("commune" %in% names(dataset)) {
        dataset = dataset[dataset[["commune"]] %in% scope, ]
    } else {
        warning("'commune' is not a column of dataset, no selection done.")
    }
    return(dataset)
}
