## In this file are grouped functions that have some geomatic utilities.
## They not need to be exported

#' @title Add commune and department information to an sf object.
#'
#' @description
#' For a sf object, this functions selects all observations that intersect any
#' commune from a given department. For those observations it add commune and
#' department information in the correspondent fields. If an observation
#' intersects more than one commune, one is chosen (more or less randomously).
#'
#' @param x sf object.
#' @param commune sf object, that describes the commune perimeters.
#' @param department character, department that should be used.
#'
#' @return sf object with both commune and department information added.
#' 
#' @encoding UTF-8
#' @author Frédéric Grelot
 
add_commune = function(x, commune, department = NULL) {
    if (!is.null(department)) {
        department = format_scope(department, type = "insee")
        commune = commune[
            commune[["department"]] == department,
        ]
    }
    commune = sf::st_transform(commune, sf::st_crs(x))
    selection = sf::st_intersects(x, commune)
    x = x[lengths(selection) > 0, ]
    selection = selection[lengths(selection) > 0]
    x[["commune"]] = commune[["commune"]][sapply(selection, '[[', 1)]

    if (is.null(department)) {
        department = format_scope(
            x[["commune"]],
            type = "insee",
            origin = "commune"
        )
    }
    x[["department"]] = department
    return(x)
}

add_eaip = function(x, path_eaip, department) {
    eaip = file_version(
        path_eaip,
        sprintf("eaip_%s.rds", format_scope(department))
    )
    if (length(eaip) == 0) {
        x[["eaip"]] = NA
    } else {
        eaip = readRDS(eaip)
        x[["eaip"]] = in_layer(x, eaip)
    }
    return(x)
}

analyse_projection = function(x, default = 2154) {
    result = rep(default, length(x))
    result[x == "LAMB93"] = 2154
    return(result)
}