% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/adapt_admin_express.R
\encoding{UTF-8}
\name{adapt_admin_express}
\alias{adapt_admin_express}
\title{Adapt Admin Express archives}
\usage{
adapt_admin_express(
  origin,
  destination,
  archive,
  layer = NULL,
  scheme = floodam.data::scheme_admin_express_3_1,
  projection = 4326,
  extension = "rds",
  journal = TRUE,
  retrieve = FALSE,
  verbose = TRUE
)
}
\arguments{
\item{origin}{character, path to the directory where archive are stored.}

\item{destination}{character, path to the directory where results should be
saved.}

\item{archive}{character, vector of archive to be adpated.}

\item{layer}{character, which layer should be treated.}

\item{scheme}{data.frame, how archive variables should be treated.}

\item{projection}{integer or object of type CRS giving projection.}

\item{extension}{character, option for extension and so format of saving of
results.}

\item{journal}{logical, should a journal file be saved.}

\item{retrieve}{logical, should the result be returned.}

\item{verbose}{logical, should the function give some sumup informations.}
}
\value{
if retrieve = TRUE, sf object of adapated data stored in archive.
This may be a list if the function implies recursive calls.
}
\description{
\code{adapt_admin_express()} treats Admin Express archives to be in a standard
format. It is suited for IGN archives. It used by default
\code{scheme_admin_express_3_1} as scheme. For older versions
\code{scheme_admin_express_2_0} is also available.

Beware that code{adapt_admin_express} will perform all possibles combinations
of archives present in origin and layers available in scheme if those
parameters are not specified.
}
\details{
The following treatment are performed:
\itemize{
\item depending on how many archives and layers are to be treated, a recursive
call may be perform to do all desired combinations.
\item archive is read with \code{\link[=read_with_scheme]{read_with_scheme()}}, which may imply that it is
uncompressed, then read (usually as a shp or a gpkg file), reprojected if
asked, and finally adapted.
\item the output is saved as rds in given destination withe\code{\link[=save_archive]{save_archive()}}. The
name of archive include a precision depending on the layer chosen. For layer
'COMMUNE', the saving is made by departments.
}
}
\examples{

\dontrun{
origin = ""
destination = tempdir()
archive = "RPG_2-0__SHP_LAMB93_FR-2018_2018-01-15.7z"
result = adapt_rpg(archive, origin, destination, verbose = TRUE, retrieve = TRUE)
}
}
\author{
Frédéric Grelot and Victor Champonnois
}
