% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/add_journal.R
\encoding{UTF-8}
\name{add_journal}
\alias{add_journal}
\title{Manage a journal for follow-up of tasks}
\usage{
add_journal(journal, task, status, id, degree = 0, verbose = TRUE)
}
\arguments{
\item{journal}{data.frame, journal to be amended. May be missing (see
details).}

\item{task}{character, description of the task. May be missing (see
details).}

\item{status}{character, description of how the task has been performed. May
be missing (see details).}

\item{id}{integer, row of the task to be amended. May be missing (see
details).}

\item{degree}{integer, indicates how deep is the task}

\item{verbose}{logical, should a message be sent. Default to TRUE.}
}
\value{
a data frame of journal information.
}
\description{
The function manages the log information for tasks that need to be linked to
each other. While the information is stored as a data.frame, it is presented
or saved as formatted character when asked to be presented (for instance when
verbose is set to TRUE).
}
\details{
If the parameter 'journal' is missing, \code{add_journal()} creates an
empty journal (a data.frame with the expected format). The data.frame have
5 columns: 'start', 'end', 'task', 'status', 'degree', and 'elapsed'.

If the parameter 'task' is not missing, and if no 'status' is given,
\code{add_journal()} adds a new line to journal, and sets 'start' to
current time, 'task' to given 'task'.

If the parameter 'status' is not missing, \code{add_journal()} try to find
to which 'task' this is relevant. This can be done by giving explictly the
'id', or by ginving the 'task'. If nothing is given, it is supposed that it
corresponds with the the last task with missing 'status'. For found 'task',
it sets 'status' to given 'status', 'end' to current time. 'elapsed' to the
formatted difftime between 'end' and 'start' with \code{floodam.data::fmt}.

If verbose == TRUE, a message is sent. If 'task' is given, a new line is
sent, but not ended by 'EOL'. When 'status' is given, message depend on what
was sent just before. If the last message was announcing the start of the
current task, it is completed with status and elapsed time. If not, a new
line is sent with the whole information (start, task, status, elapsed).
'degree' is used to have some tabular formatting. The message sent is
formatted by \code{floodam.date:::format_journal}.
}
\examples{

add_journal()
add_journal(status = "Nothing to be done...", verbose = FALSE)
{
journal = add_journal(
  task = sprintf(
    "maintain gaspar with floodam.data (\%s)",
    utils::packageVersion("floodam.data")
  )
)
Sys.sleep(.1)
journal = add_journal(journal, task = "download_gaspar", degree = 1)
journal = add_journal(journal, task = "adapt_gaspar", degree = 1)
Sys.sleep(.1)
journal = add_journal(journal, task = "alert_gaspar", degree = 1)
journal = add_journal(journal, status = "Done", id = 2)
Sys.sleep(.1)
journal = add_journal(journal, status = "Done", task = "alert_gaspar")
journal = add_journal(journal, status = "Done")
journal = add_journal(journal, status = "Done")
journal
}
}
\author{
Frédéric Grelot
}
