% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/analyse_dwelling.R
\encoding{UTF-8}
\name{analyse_dwelling}
\alias{analyse_dwelling}
\title{Analyse dwellings in the BD Topo v3 reporting some elementary results}
\usage{
analyse_dwelling(
  origin,
  destination = gsub("building", "dwelling", origin),
  archive,
  category = "Résidentiel",
  dwelling_mean_surf = (90 * 1.2),
  report = TRUE,
  retrieve = TRUE,
  verbose = TRUE
)
}
\arguments{
\item{origin}{character, path to the directory where archive are stored.}

\item{destination}{character, path to the directory where output should be
saved. The function expects it to be the same provided to function.
\code{extract_dwelling()} if it has been previously invoked in the analysis.
Default to same path as origin but substituting automatically keyword
'building' by keyword 'dwelling' when possible}

\item{archive}{character, vector of filenames to be processed. If missing,
analyse_dwelling is recursively called on all admissible archives found in
origin.}

\item{category}{character, focus of the analysis. Default to "Résidentiel".}

\item{dwelling_mean_surf}{numeric, average surface of a dwelling in France.
Default to 90 m^2, which is from adapted to the GT AMC's methodology.}

\item{report}{logical, should the function create a summary report with the
outputs. Default to TRUE.}

\item{retrieve}{logical, should the output of the function be returned.}

\item{verbose}{logical, should the function send some messages while running.}
}
\value{
A list of analysis if 'retrieve = TRUE'.
}
\description{
The function performs several analysis in order to check the validity and the
consistency of the calculations made by functions \code{extract_building()} and
\code{extract_dwelling()} over the BD Topo (version 3). The function focuses
by default on residential constructions. In addition to returning a list, the
function creates tables in csv format and png image files in path.
}
\examples{
\dontrun{

# calling function. Long version
   tab_building = analyse_dwelling(
       archive = "bdtopo-building-2022-03-15-D034.rds",
       origin = path_building,
       destination = path_dwelling,
       category = "Résidentiel",
       vintage = "2022-03-15"
   )

# calling function. short version
   tab_building = analyse_dwelling(
       archive = "bdtopo-building-2022-03-15-D034.rds",
       origin = path_building,
       destination = path_dwelling
   )

# calling function. recursive version
   analyse_dwelling(origin = path_building)
}

}
\author{
David Nortes Martinez et Frédéric Grelot
}
