% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/format_archive.R
\encoding{UTF-8}
\name{format_archive}
\alias{format_archive}
\title{Format name of archives to be consistent and predictible}
\usage{
format_archive(x, extension, origin = c("floodam.data", "ign", "version"))
}
\arguments{
\item{x}{character, a named character.}

\item{extension}{character, if given, it will overrule what is in x.}

\item{origin}{character, default value to "floodam.data". See details.}
}
\value{
A vector of formatted names.
}
\description{
\code{format_archive()} creates formatted names for archives given some
informations on the data contained in archives and the type of format aimed
at.

It can be as the reciprocal function of
\code{\link[=analyse_archive]{analyse_archive()}}.
}
\details{
\code{x} should be a named character where informations used for formatting
the result ar stored. If some informations are missing, basically NA will be
used, and those NA will be post-treated depending on origin.

If origin is "floodam.data", \code{format_archive()} returns archive names
formatted with this general scheme: data_precision_scope_date. Missing
informations in \code{x} produce an adaptation of the scheme. For instance,
if nothing is given for "scope" in x or if x["scope"] is "NA", the resulting
scheme will be data_precision_date.

If origin is "ign", \code{format_archive()} returns names formatted with
this scheme: data-type_version_precision_format_projection_scope_date.
Missing informations in \code{x} are replaced by "".

If origin is "version", \code{format_archive()} returns names formatted with
this scheme: version_precision_format_projection_scope. Missing informations
in \code{x} are replaced by ".*". No extension information is used.

If extension is given, the extension is added to be name produced. I no
extension is given, x["extension"] will be used if not NA.
}
\examples{
archive = "ADMIN-EXPRESS-COG_3-1__SHP_RGAF09UTM20_GLP_2022-04-15.7z"
x = analyse_archive(archive)

format_archive(x, origin = "ign")
archive == format_archive(x, origin = "ign")

format_archive(x, extension = "rds", origin = "ign")
format_archive(x, extension = "rds")
x["precision"] = "commune"
x["scope"] = "D972"
format_archive(x, extension = "rds")

format_archive(origin = "version")
}
\seealso{
\code{\link[=analyse_archive]{analyse_archive()}}
}
\author{
Frédéric Grelot
}
