% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/read_with_scheme.R
\encoding{UTF-8}
\name{read_with_scheme}
\alias{read_with_scheme}
\alias{read_csv_with_scheme}
\alias{read_shp_with_scheme}
\alias{read_gpkg_with_scheme}
\alias{read_shp_from_7z}
\alias{read_gpkg_from_7z}
\title{Read data with a scheme}
\usage{
read_with_scheme(
  x,
  scheme = NULL,
  projection = NA,
  layer,
  type,
  extension = tools::file_ext(x)
)

read_csv_with_scheme(x, scheme = NULL, projection = NA)

read_shp_with_scheme(x, scheme = NULL, projection = NA, layer)

read_gpkg_with_scheme(x, scheme = NULL, projection = NA, layer)

read_shp_from_7z(x, scheme = NULL, projection = NA, layer)

read_gpkg_from_7z(x, scheme = NULL, projection = NA, layer)
}
\arguments{
\item{x}{character, path of the data to be read.}

\item{scheme}{data.frame, scheme to be applied.}

\item{projection}{something that will be used in the option "crs" of
\code{sf::st_as_sf}.}

\item{layer}{character, indicates the layer to be read for data organized by
layers.}

\item{type}{character, indicates the type of data that should be read.}

\item{extension}{character, indicate the exrtension of the archive. If
missing will be guessed from x.}
}
\value{
data adapted, either a data.frame or a 'sf' objects.
}
\description{
\code{read_with_scheme()} is a wrapper for more specific functions. It uses
\code{type} and \code{extension} to call the good function. If those
parameters are not specified it tries to guess them from the name of the
archive included in \code{x}.

\code{read_csv_with_scheme()} relies on \code{data.table::fread} to read
tabular data, and to apply a scheme. The idea is to used the efficiency of
\code{fread()} to read more quickly data (and without too many specifications
on "sep" and "dec"), and to used some options to read only data that will be
kept with original format given in scheme. As almost, everyhting is done
after reading, the remaining part of applying a scheme is also one: final
format is applied, and if, some "lon" and "lat" is found, data is transformed
in sf object.

\code{read_shp_with_scheme()} relies on \code{sf::st_read} to read gpkg data.
If given, projection is changed. If given scheme is applyed through
\code{apply_scheme()}. It is supposed that the scheme given is organized with a
layer column.

\code{read_gpkg_with_scheme()} relies on \code{sf::st_read} to read gpkg data.
If given, projection is changed. If given scheme is applyed through
\code{apply_scheme()}. It is supposed that the scheme given is organized with a
layer column.

\code{read_shp_from_7z} uses a system call to 7z to uncompress a
7z archive. It looks specifically for files that correspond to given layer.
It then reads the uncompressed gpkg file with a call to
\code{read_shp_with_scheme()}.

\code{read_gkpg_from_7z} uses a system call to 7z to uncompress a 7z archive.
It looks specifically for files with extension gkpg, and presumes that there
is only one. It then reads the uncompressed gpkg file with a call to
\code{read_gpkg_with_scheme()}.
}
\details{
If 'scheme' is NULL (default). \code{data.table::fread} is used with
colClasses set to "character".

If 'projection' is NA (default), no crs is given \code{sf::to st_as_sf}.
}
\author{
Frédéric Grelot
}
