test_that("Test format_archive",
    {
        analyse = c(
            data = "admin-express-cog",
            version = "2-0",
            precision = "departement",
            type = "SHP",
            projection = "LAMB93",
            scope = 1,
            vintage = "2022-04-15",
            year = "2022",
            extension = "7z"
        )

        # origin = "floodam.data" (default)
        ## format complet, scope retravaillé
        expect_identical(
            format_archive(analyse),
            "admin-express-cog_departement_D001_2022-04-15.7z"
        )
        ## utilisation de extension
        expect_identical(
            format_archive(analyse, extension = "rds"),
            "admin-express-cog_departement_D001_2022-04-15.rds"
        )
        ## Pas de précision
        expect_identical(
            format_archive(analyse[-3], extension = "rds"),
            "admin-express-cog_D001_2022-04-15.rds"
        )
        ## Pas de précision, pas de scope car non reconnu
        analyse[["scope"]] = "FRA"
        expect_identical(
            format_archive(analyse[-3], extension = "rds"),
            "admin-express-cog_2022-04-15.rds"
        )
        ## Pas de précision, ni de vintage, pas de scope car non reconnu
        expect_identical(
            format_archive(analyse[-c(3, 7)], extension = "rds"),
            "admin-express-cog.rds"
        )
        ## Rien
        expect_identical(
            format_archive(analyse[-c(1, 3, 7)], extension = "rds"),
            ".rds"
        )

        # origin = "ign"
        ## format complet, scope non retravaillé
        expect_identical(
            format_archive(analyse, origin = "ign"),
            "ADMIN-EXPRESS-COG_2-0_departement_SHP_LAMB93_FRA_2022-04-15.7z"
        )
        ## format complet, scope retravaillé
        analyse["scope"] = 1
        expect_identical(
            format_archive(analyse, origin = "ign"),
            "ADMIN-EXPRESS-COG_2-0_departement_SHP_LAMB93_D001_2022-04-15.7z"
        )
        # Pas de précision
        expect_identical(
            format_archive(analyse[-3], origin = "ign"),
            "ADMIN-EXPRESS-COG_2-0__SHP_LAMB93_D001_2022-04-15.7z"
        )
        # Pas de précision, ni de type
        expect_identical(
            format_archive(analyse[-(3:4)], origin = "ign"),
            "ADMIN-EXPRESS-COG_2-0___LAMB93_D001_2022-04-15.7z"
        )

        # origin = "version"
        ## Pattern général
        expect_identical(
            format_archive(origin = "version"),
            ".*_.*_.*_.*_.*"
        )
        ## Pattern complet, scope retravaillé
        expect_identical(
            format_archive(analyse, origin = "version"),
            "2-0_departement_SHP_LAMB93_D001"
        )
        ## Pattern complet, scope non retravaillé
        analyse[["scope"]] = "R76"
        expect_identical(
            format_archive(analyse, origin = "version"),
            "2-0_departement_SHP_LAMB93_R76"
        )
        ## Pas de précision
        expect_identical(
            format_archive(analyse[-3], origin = "version"),
            "2-0_.*_SHP_LAMB93_R76"
        )
    }
)
